@@ -1,7 +1,6 @@
-from setux.main import __version__
-from setux.main.logger import info
+from setux.core import __version__
 
-from . import Module
+from . import Module, info
 
 
 class Distro(Module):
